==> bootstrap-core-1.0.58-sources.jar: com/turbospaces/ups/UPSs.java <==
package com.turbospaces.ups;

import java.nio.charset.StandardCharsets;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Optional;
import java.util.Properties;
import java.util.function.Predicate;
import java.util.stream.Collectors;

import org.springframework.cloud.Cloud;
import org.springframework.cloud.CloudConnector;
import org.springframework.cloud.service.ServiceInfo;
import org.springframework.cloud.service.UriBasedServiceInfo;

import com.turbospaces.boot.Bootstrap;
import com.turbospaces.cfg.ApplicationConfig;

public interface UPSs {
    //
    // ~ GIT
    //
    String CFG = "cfg";

    //
    // ~ multiple peers potentially
    //
    String KAFKA = "kafka";
    String ELASTIC_SEARCH = "elastic-search";

    String SENTRY = "sentry";
    String INFLUX = "influx";
    String JAEGER = "jaeger";
    String REDIS = "redis";

    // ~ load testing
    String LOCUST = "locust";

    //
    // ~ DDL
    //
    String POSTGRES_OWNER = "postgres-owner";
    String H2_OWNER = "h2-owner";

    //
    // ~ DML
    //
    String POSTGRES_APP = "postgres-app";
    String H2_APP = "h2-app";

    //
    // ~ quartz
    //
    String QUARTZ_APP = "quartz-app";

    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> Optional<T> findServiceInfoByType(Cloud cloud, Class<T> serviceInfoClass) {
        List<ServiceInfo> serviceInfos = cloud.getServiceInfos();
        List<ServiceInfo> l = serviceInfos.stream().filter(new Predicate<ServiceInfo>() {
            @Override
            public boolean test(ServiceInfo input) {
                return input.getClass().equals(serviceInfoClass);
            }
        }).collect(Collectors.toList());
        Iterator<ServiceInfo> it = l.iterator();
        if (it.hasNext()) {
            T next = (T) it.next();
            if (it.hasNext()) {
                throw new IllegalArgumentException("unable to find unique service by type");
            }
            return Optional.of(next);
        }
        return Optional.empty();
    }
    static <T extends ServiceInfo> T findRequiredServiceInfoByType(Bootstrap boot, Class<T> serviceInfoClass) {
        return findServiceInfoByType(boot.cloud(), serviceInfoClass).get();
    }
    static <T extends ServiceInfo> T findRequiredServiceInfoByType(Cloud cloud, Class<T> serviceInfoClass) {
        return findServiceInfoByType(cloud, serviceInfoClass).get();
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(List<ServiceInfo> serviceInfos, String name) {
        return (Optional<T>) serviceInfos.stream().filter(new Predicate<ServiceInfo>() {
            @Override
            public boolean test(ServiceInfo input) {
                return input.getId().equals(name);
            }
        }).findAny();
    }
    static <T extends ServiceInfo> Optional<T> findScopedServiceInfoByName(String scope, Bootstrap bootstrap, String name) {
        Optional<T> opt = findServiceInfoByName(bootstrap, scope + "-" + name);
        if (opt.isPresent()) {
            return opt;
        }
        opt = findServiceInfoByName(bootstrap.cloud(), name);
        return opt;
    }
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(Bootstrap boot, String name) {
        List<ServiceInfo> serviceInfos = boot.cloud().getServiceInfos();
        return findServiceInfoByName(serviceInfos, name);
    }
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(Cloud cloud, String name) {
        List<ServiceInfo> serviceInfos = cloud.getServiceInfos();
        return findServiceInfoByName(serviceInfos, name);
    }
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(CloudConnector connector, String name) {
        List<ServiceInfo> serviceInfos = connector.getServiceInfos();
        return findServiceInfoByName(serviceInfos, name);
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> T findScopedRequiredServiceInfoByName(String scope, Bootstrap bootstrap, String name) {
        Optional<ServiceInfo> opt = findServiceInfoByName(bootstrap, scope + "-" + name);
        if (opt.isPresent()) {
            return (T) opt.get();
        }
        opt = findServiceInfoByName(bootstrap, name);
        return (T) opt.get();
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> T findRequiredServiceInfoByName(Bootstrap bootstrap, String name) {
        return (T) findServiceInfoByName(bootstrap.cloud(), name).get();
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> T findRequiredServiceInfoByName(Cloud cloud, String name) {
        return (T) findServiceInfoByName(cloud, name).get();
    }
    static ApplicationConfig addUserProvideService(ApplicationConfig cfg, ServiceInfo service) {
        return addUserProvideServices(cfg, Collections.singletonList(service));
    }
    static ApplicationConfig addUserProvideServices(ApplicationConfig cfg, List<ServiceInfo> services) {
        Properties props = new Properties();
        addUserProvideServices(props, services);
        cfg.setLocalProperties(props);
        return cfg;
    }
    static Properties addUserProvideServices(Properties props, List<ServiceInfo> services) {
        for (ServiceInfo info : services) {
            String uri = null;
            if (info instanceof UriBasedServiceInfo) {
                uri = ((UriBasedServiceInfo) info).getUri();
            } else if (info instanceof RawServiceInfo) {
                uri = new String(((RawServiceInfo) info).getPayload(), StandardCharsets.UTF_8);
            } else {
                throw new IllegalArgumentException();
            }

            props.put("service." + info.getId() + ".uri", uri);
        }
        return props;
    }
}

==> bootstrap-core-1.0.59-sources.jar: com/turbospaces/ups/UPSs.java <==
package com.turbospaces.ups;

import java.nio.charset.StandardCharsets;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Optional;
import java.util.Properties;
import java.util.function.Predicate;
import java.util.stream.Collectors;

import org.springframework.cloud.Cloud;
import org.springframework.cloud.CloudConnector;
import org.springframework.cloud.service.ServiceInfo;
import org.springframework.cloud.service.UriBasedServiceInfo;

import com.turbospaces.boot.Bootstrap;
import com.turbospaces.cfg.ApplicationConfig;

public interface UPSs {
    //
    // ~ GIT
    //
    String CFG = "cfg";

    //
    // ~ multiple peers potentially
    //
    String KAFKA = "kafka";
    String ELASTIC_SEARCH = "elastic-search";

    String SENTRY = "sentry";
    String INFLUX = "influx";
    String JAEGER = "jaeger";
    String REDIS = "redis";

    // ~ load testing
    String LOCUST = "locust";

    //
    // ~ DDL
    //
    String POSTGRES_OWNER = "postgres-owner";
    String H2_OWNER = "h2-owner";

    //
    // ~ DML
    //
    String POSTGRES_APP = "postgres-app";
    String H2_APP = "h2-app";

    //
    // ~ quartz
    //
    String QUARTZ_APP = "quartz-app";

    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> Optional<T> findServiceInfoByType(Cloud cloud, Class<T> serviceInfoClass) {
        List<ServiceInfo> serviceInfos = cloud.getServiceInfos();
        List<ServiceInfo> l = serviceInfos.stream().filter(new Predicate<ServiceInfo>() {
            @Override
            public boolean test(ServiceInfo input) {
                return input.getClass().equals(serviceInfoClass);
            }
        }).collect(Collectors.toList());
        Iterator<ServiceInfo> it = l.iterator();
        if (it.hasNext()) {
            T next = (T) it.next();
            if (it.hasNext()) {
                throw new IllegalArgumentException("unable to find unique service by type");
            }
            return Optional.of(next);
        }
        return Optional.empty();
    }
    static <T extends ServiceInfo> T findRequiredServiceInfoByType(Bootstrap boot, Class<T> serviceInfoClass) {
        return findServiceInfoByType(boot.cloud(), serviceInfoClass).get();
    }
    static <T extends ServiceInfo> T findRequiredServiceInfoByType(Cloud cloud, Class<T> serviceInfoClass) {
        return findServiceInfoByType(cloud, serviceInfoClass).get();
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(List<ServiceInfo> serviceInfos, String name) {
        return (Optional<T>) serviceInfos.stream().filter(new Predicate<ServiceInfo>() {
            @Override
            public boolean test(ServiceInfo input) {
                return input.getId().equals(name);
            }
        }).findAny();
    }
    static <T extends ServiceInfo> Optional<T> findScopedServiceInfoByName(String scope, Bootstrap bootstrap, String name) {
        Optional<T> opt = findServiceInfoByName(bootstrap, scope + "-" + name);
        if (opt.isPresent()) {
            return opt;
        }
        opt = findServiceInfoByName(bootstrap.cloud(), name);
        return opt;
    }
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(Bootstrap boot, String name) {
        List<ServiceInfo> serviceInfos = boot.cloud().getServiceInfos();
        return findServiceInfoByName(serviceInfos, name);
    }
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(Cloud cloud, String name) {
        List<ServiceInfo> serviceInfos = cloud.getServiceInfos();
        return findServiceInfoByName(serviceInfos, name);
    }
    static <T extends ServiceInfo> Optional<T> findServiceInfoByName(CloudConnector connector, String name) {
        List<ServiceInfo> serviceInfos = connector.getServiceInfos();
        return findServiceInfoByName(serviceInfos, name);
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> T findScopedRequiredServiceInfoByName(String scope, Bootstrap bootstrap, String name) {
        Optional<ServiceInfo> opt = findServiceInfoByName(bootstrap, scope + "-" + name);
        if (opt.isPresent()) {
            return (T) opt.get();
        }
        opt = findServiceInfoByName(bootstrap, name);
        return (T) opt.get();
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> T findRequiredServiceInfoByName(Bootstrap bootstrap, String name) {
        return (T) findServiceInfoByName(bootstrap.cloud(), name).get();
    }
    @SuppressWarnings("unchecked")
    static <T extends ServiceInfo> T findRequiredServiceInfoByName(Cloud cloud, String name) {
        return (T) findServiceInfoByName(cloud, name).get();
    }
    static ApplicationConfig addUserProvideService(ApplicationConfig cfg, ServiceInfo service) {
        return addUserProvideServices(cfg, Collections.singletonList(service));
    }
    static ApplicationConfig addUserProvideServices(ApplicationConfig cfg, Collection<ServiceInfo> services) {
        Properties props = new Properties();
        addUserProvideServices(props, services);
        cfg.setLocalProperties(props);
        return cfg;
    }
    static Properties addUserProvideServices(Properties props, Collection<ServiceInfo> services) {
        for (ServiceInfo info : services) {
            String uri = null;
            if (info instanceof UriBasedServiceInfo) {
                uri = ((UriBasedServiceInfo) info).getUri();
            } else if (info instanceof RawServiceInfo) {
                uri = new String(((RawServiceInfo) info).getPayload(), StandardCharsets.UTF_8);
            } else {
                throw new IllegalArgumentException();
            }

            props.put("service." + info.getId() + ".uri", uri);
        }
        return props;
    }
}
